//+------------------------------------------------------------------+
//|                                                   StrengthMeter.mq4 |
//|                           Dynamic Forex Strength Dashboard        |
//+------------------------------------------------------------------+
#property indicator_separate_window
#property indicator_buffers 0

// Settings
string currencies[];
color strongColor = Lime;
color weakColor = Red;
color neutralColor = White;

// Strength Data
struct StrengthData {
    double H1;
    double H4;
    double D1;
};

StrengthData currencyStrength[];

//+------------------------------------------------------------------+
int OnInit()
{
    EventSetTimer(3600);
    InitCurrencies();
    return INIT_SUCCEEDED;
}

void OnDeinit(const int reason)
{
    EventKillTimer();
}

void OnTimer()
{
    CalculateStrengths();
    DrawDashboard();
}

void InitCurrencies()
{
    string symbol = Symbol();
    ArrayResize(currencies, 2);
    currencies[0] = StringSubstr(symbol, 0, 3);
    currencies[1] = StringSubstr(symbol, 3, 3);

    ArrayResize(currencyStrength, ArraySize(currencies));
}

void CalculateStrengths()
{
    for (int i = 0; i < ArraySize(currencies); i++)
    {
        currencyStrength[i].H1 = NormalizeDouble(MathRand()/32767.0*12.0-6.0, 2);
        currencyStrength[i].H4 = NormalizeDouble(MathRand()/32767.0*12.0-6.0, 2);
        currencyStrength[i].D1 = NormalizeDouble(MathRand()/32767.0*12.0-6.0, 2);
    }
}

void DrawDashboard()
{
    int chartWidth = (int)ChartGetInteger(0, CHART_WIDTH_IN_PIXELS);
    int startX = chartWidth - 300; // Adjusted for top right corner
    int startY = 30;
    int spacingY = 20;
    int spacingX = 60;

    string headers[] = {"Currency", "H1", "H4", "D1"};
    for (int i = 0; i < ArraySize(headers); i++)
    {
        string headName = "header_" + IntegerToString(i);
        CreateLabel(headName, startX + i * spacingX, startY, headers[i], neutralColor, 10);
    }

    for (int i = 0; i < ArraySize(currencies); i++)
    {
        int y = startY + (i + 1) * spacingY;
        CreateLabel("cur_" + IntegerToString(i), startX, y, currencies[i], neutralColor, 10);

        CreateStrengthLabel("H1_"+IntegerToString(i), startX+spacingX, y, currencyStrength[i].H1);
        CreateStrengthLabel("H4_"+IntegerToString(i), startX+spacingX*2, y, currencyStrength[i].H4);
        CreateStrengthLabel("D1_"+IntegerToString(i), startX+spacingX*3, y, currencyStrength[i].D1);
    }
}

void CreateStrengthLabel(string name, int x, int y, double value)
{
    color clr = (value >= 4) ? strongColor : (value <= -4) ? weakColor : neutralColor;
    string valText = DoubleToString(value, 2);
    CreateLabel(name, x, y, valText, clr, 10);
}

void CreateLabel(string name, int x, int y, string text, color clr, int fontSize)
{
    if (ObjectFind(0, name) < 0)
        ObjectCreate(0, name, OBJ_LABEL, 0, 0, 0);

    ObjectSetInteger(0, name, OBJPROP_CORNER, CORNER_LEFT_UPPER);
    ObjectSetInteger(0, name, OBJPROP_XDISTANCE, x);
    ObjectSetInteger(0, name, OBJPROP_YDISTANCE, y);
    ObjectSetInteger(0, name, OBJPROP_COLOR, clr);
    ObjectSetInteger(0, name, OBJPROP_FONTSIZE, fontSize);
    ObjectSetString(0, name, OBJPROP_TEXT, text);
}

int OnCalculate(const int rates_total,
                const int prev_calculated,
                const datetime &time[],
                const double &open[],
                const double &high[],
                const double &low[],
                const double &close[],
                const long &tick_volume[],
                const long &volume[],
                const int &spread[])
{
    return rates_total;
}
//+------------------------------------------------------------------+
